package com.nokia.controller;

import com.alibaba.fastjson.JSONObject;
import com.nokia.common.R;
import com.nokia.service.Flow.FlowServiceImpl;
import com.nokia.vo.FlowRoleVo;
import com.nokia.vo.FlowUserVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 提供给工作流的api
 */
@RestController
@RequestMapping("rest")
public class FlowApiController {

    private final FlowServiceImpl flowServiceImpl;

    @Autowired
    public FlowApiController(FlowServiceImpl flowServiceImpl) {
        this.flowServiceImpl = flowServiceImpl;
    }

    @PostMapping("flow/api")
    @ResponseBody
    public R flowApi(@RequestBody JSONObject jsonObject) {
        String callType = jsonObject.getString("callType");
        if (callType == null) {
            return R.error().message("输入必须包含callType");
        }
        switch (callType) {
            case "findRoleList":
                return findRoleList(jsonObject);
            case "findToPage":
                return findToPage();
            case "getByLoginId":
                return getByLoginId(jsonObject);
            case "get":
                return get(jsonObject);
            case "findRoleIdByUserId":
                return findRoleIdByUserId(jsonObject);
            case "findUserIdByRoleId":
                return findUserIdByRoleId(jsonObject);
            case "findAuthorizedUser":
                return findAuthorizedUser(jsonObject);
            default:
                return R.error().message("callType类型错误");
        }
    }

    public R findRoleList(JSONObject jsonObject) {
        String username = jsonObject.getString("userName");
        if (username == null || username.equals("")) {
            return R.ok().data(flowServiceImpl.findRoleList());
        }
        List<FlowRoleVo> roleList = flowServiceImpl.findRoleList(username);
        return R.ok().data(roleList);
    }

    public R findToPage() {
        return R.ok().data(flowServiceImpl.findToPage());
    }

    public R getByLoginId(JSONObject jsonObject) {
        String loginId = jsonObject.getString("loginId");
        if (loginId == null || loginId.equals("")) {
            return R.error().message("输入必须包含loginId");
        }
        FlowUserVo flowUserVo = flowServiceImpl.getByLoginId(loginId);
        return R.ok().data(flowUserVo);
    }

    public R get(JSONObject jsonObject) {
        Integer userId = null;
        try {
            userId = jsonObject.getInteger("userId");
        } catch (NumberFormatException e) {
            return R.error().message("输入的userId必须为整数格式");
        }
        if (userId == null) {
            return R.error().message("输入必须包含userId");
        }
        FlowUserVo flowUserVo = flowServiceImpl.getByUserId(userId);
        return R.ok().data(flowUserVo);
    }

    public R findRoleIdByUserId(JSONObject jsonObject) {
        Integer userId = null;
        try {
            userId = jsonObject.getInteger("userId");
        } catch (NumberFormatException e) {
            return R.error().message("输入的userId必须为整数格式");
        }
        if (userId == null) {
            return R.error().message("输入必须包含userId");
        }
        List<Integer> roleIdList = flowServiceImpl.findRoleIdByUserId(userId);
        return R.ok().data(roleIdList);
    }

    public R findUserIdByRoleId(JSONObject jsonObject) {
        Integer roleId = null;
        try {
            roleId = jsonObject.getInteger("roleId");
        } catch (NumberFormatException e) {
            return R.error().message("输入的roleId必须为整数格式");
        }
        if (roleId == null) {
            return R.error().message("输入必须包含roleId");
        }
        List<Integer> userIdList = flowServiceImpl.findUserIdByRoleId(roleId);
        return R.ok().data(userIdList);
    }

    public R findAuthorizedUser(JSONObject jsonObject) {
        String loginId = jsonObject.getString("loginId");
        loginId = loginId == null || loginId.equals("") ? null : loginId.trim();
        Integer roleId = null;
        try {
            roleId = jsonObject.getInteger("roleId");
        } catch (NumberFormatException ignored) {
        }
        String userName = jsonObject.getString("userName");
        userName = userName == null || userName.equals("") ? null : userName.trim();
        List<FlowUserVo> flowUserVos = flowServiceImpl.findAuthorizedUser(loginId, roleId, userName);
        return R.ok().data(flowUserVos);
    }
}
