package com.nokia.controller;

import com.nokia.common.R;
import com.nokia.pojo.UserEntity;
import com.nokia.service.user.UserServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("rest/api/user")
public class UserController {
    private final UserServiceImpl userServiceImpl;

    @Autowired
    public UserController(UserServiceImpl userServiceImpl) {
        this.userServiceImpl = userServiceImpl;
    }

    @PostMapping("list")
    @ResponseBody
    public R list() {
        List<UserEntity> userEntities = userServiceImpl.list();
        return R.ok().data(userEntities);
    }

    @PostMapping("add")
    @ResponseBody
    public R add(@RequestBody UserEntity user) {
        if (user.getLoginName() == null || user.getLoginName().equals("")) {
            return R.error().message("LoginName不能为空");
        }
        String msg = userServiceImpl.add(user);
        if (msg.equals("ok")) {
            return R.ok().message("添加成功");
        } else {
            return R.error().message(msg);
        }
    }

    @PostMapping("/delete/id/{userId}")
    public R delete(@PathVariable Integer userId) {
        if (null == userId) {
            return R.error().message("userId 不能为空");
        }
        String delete = userServiceImpl.delete(userId);
        if (delete.equals("ok")) {
            return R.ok().message("删除成功");
        } else {
            return R.error().message(delete);
        }
    }

    @PostMapping("/update/id/{userId}")
    public R update(@PathVariable Integer userId, @RequestBody UserEntity userEntity) {
        if (null == userEntity) {
            return R.error().message("userEntity 为空");
        }
        userEntity.setUserId(userId);
        String update = userServiceImpl.update(userEntity);
        if (update.equals("ok")) {
            return R.ok().message("修改成功");
        } else {
            return R.error().message(update);
        }
    }

    @PostMapping("/select/id/{userId}")
    public Map<String, Object> select(@PathVariable Integer userId) {

        return userServiceImpl.select(userId);
    }
}
